include module type of Liquidsoap_lang.Lang_string

val generate_id : category:string -> string -> string
